<?php

namespace App\Http\Controllers;

use App\Http\Requests\BlfSettingsRequest;
use App\Http\Requests\GroupSettingsRequest;
use App\Http\Requests\UpdateIceServersRequest;
use App\Models\AppSetting;
use Illuminate\Http\JsonResponse;
use Illuminate\Support\Facades\Log;
use Exception;

class AppController extends Controller
{
    private PbxApiController $eventLog;

    public function __construct()
    {
        $this->eventLog = new PbxApiController();
    }

    public function getVersion(): JsonResponse
    {
        try {
            return response()->json([
                'version' => app(\App\Utils\AppStatus::class)->getVersion('vitxi')
            ]);
        } catch (Exception $exception) {
            Log::error('Version fetch failed', ['error' => $exception->getMessage()]);
            return response()->json(['error' => $exception->getMessage()], 500);
        }
    }

    public function getIceServers(): JsonResponse
    {
        try {
            $iceServers = AppSetting::getSetting('network', 'iceServers')->firstOrFail();
            return response()->json($iceServers);
        } catch (Exception $exception) {
            Log::error('Ice servers fetch failed', ['error' => $exception->getMessage()]);
            return response()->json(['error' => $exception->getMessage()], 500);
        }
    }

    public function updateIceServers(UpdateIceServersRequest $request): JsonResponse
    {
        try {
            $validated = $request->validated();
            $iceServers = $validated['iceServers'];

            $setting = AppSetting::updateOrCreate(
                ['key' => 'iceServers', 'type' => 'network'],
                ['value' => $iceServers]
            );

            $user = auth()->user();
            $this->logEvent(
                $user,
                'Ice Servers',
                ['iceServers' => $iceServers],
                $request
            );

            return response()->json($setting);
        } catch (Exception $exception) {
            Log::error('Ice servers update failed', ['error' => $exception->getMessage()]);
            return response()->json(['error' => $exception->getMessage()], 500);
        }
    }

    public function getBlfSettings(): JsonResponse
    {
        try {
            $settings = AppSetting::where('type', 'blf')
                ->get()
                ->pluck('value', 'key');

            return response()->json($settings);
        } catch (Exception $e) {
            Log::error('BLF settings fetch failed', ['error' => $e->getMessage()]);
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }

    public function updateBlfSettings(BlfSettingsRequest $request): JsonResponse
    {
        try {
            $validated = $request->validated();

            $setting = AppSetting::updateOrCreate(
                ['type' => 'blf', 'key' => 'limit'],
                ['value' => $validated['limit']]
            );

            $user = auth()->user();
            $this->logEvent(
                $user,
                'BLF Settings',
                ['limit' => $validated['limit']],
                $request
            );

            return response()->json([
                'message' => __('settings_update_success'),
                'setting' => $setting
            ]);
        } catch (Exception $e) {
            Log::error('BLF settings update failed', ['error' => $e->getMessage()]);
            return response()->json(['error' => $e->getMessage()], 500);
        }
    }

    public function getGroupSettings(): JsonResponse
    {
        try {
            $settings = AppSetting::where('type', 'groups')
                ->get()
                ->pluck('value', 'key');

            return response()->json($settings);
        } catch (Exception $e) {
            return response()->json([
                'error' => $e->getMessage()
            ], 500);
        }
    }

    public function updateGroupSettings(GroupSettingsRequest $request): JsonResponse
    {
        try {
            $validated = $request->validated();
            $memberLimit = $validated['member_limit'] ?? 150;

            $setting = AppSetting::updateOrCreate(
                ['type' => 'groups', 'key' => 'member_limit'],
                ['value' => $memberLimit]
            );

            $user = auth()->user();
            $this->logEvent(
                $user,
                'Group Settings',
                ['limit' => $memberLimit],
                $request
            );

            return response()->json([
                'message' => __('settings_update_success'),
                'setting' => $setting
            ]);
        } catch (Exception $e) {
            return response()->json([
                'error' => $e->getMessage()
            ], 500);
        }
    }

    private function logEvent($user, string $module, array $data, $request): void
    {
        $this->eventLog->saveEvents(
            $user->tenant_id,
            $module,
            'update',
            $data,
            $user->user_name,
            $user->id,
            [],
            $request->ip(),
            $request->userAgent()
        );
    }
}
